## Dispatching problems

\n

Dispatching problems involves taking problems under a given category and re-assigning one low priority from the busiest to the least busy user.To do so, you need to:

\n

\n
- Find the user that has the most problems assigned to them and the one that has the least number of problems assigned to them. This is done by finding the information in the report for the given category, which is named 'Problems for category {category_name}'. The list of reports can be found here
\n
- Find a lowest priority problem (priority=5) of the appropriate category assigned to the user. This can be done by filtering the problem list
\n
- Assign this problem to the least busy user